[evolution-data-server/october-code-drop-pre-api-change] Manually reverting API changes for this branch.



commit d02459a015b6cd33cd0a9d53f2457c07f885a9e2
Author: Tristan Van Berkom <tristanvb openismus com>
Date:   Sun Oct 27 17:40:07 2013 +0100

    Manually reverting API changes for this branch.
    
    The purpose of this branch is to stick to the same
    API as the one delivered in this tag:
        OPENISMUS_3_8_DROP_28_08_2013

 addressbook/backends/file/e-book-backend-file.c    |    2 +-
 .../libebook-contacts/e-book-contacts-types.h      |   12 +++---
 addressbook/libebook/e-book-client-cursor.c        |    8 ++--
 addressbook/libebook/e-book-client-cursor.h        |    2 +-
 addressbook/libebook/e-book-client.c               |   18 +++++-----
 addressbook/libebook/e-book-client.h               |    4 +-
 .../libedata-book/e-book-backend-sqlitedb.c        |   34 ++++++++++----------
 .../libedata-book/e-book-backend-sqlitedb.h        |   10 +++---
 addressbook/libedata-book/e-book-backend.c         |    4 +-
 addressbook/libedata-book/e-book-backend.h         |    4 +-
 .../libedata-book/e-data-book-cursor-sqlite.c      |   16 +++++-----
 .../libedata-book/e-data-book-cursor-sqlite.h      |    2 +-
 addressbook/libedata-book/e-data-book.c            |   10 +++---
 tests/cursor-example/cursor-data.c                 |    2 +-
 tests/cursor-example/cursor-example.c              |    2 +-
 tests/libebook/client/test-client-cursor-create.c  |    4 +-
 .../client/test-client-cursor-operations.c         |    2 +-
 tests/libedata-book/data-test-utils.c              |    6 ++--
 tests/libedata-book/data-test-utils.h              |    4 +-
 tests/libedata-book/test-sqlite-create-cursor.c    |    8 ++--
 tests/libedata-book/test-sqlite-cursor-calculate.c |    4 +-
 .../test-sqlite-cursor-move-by-en-US.c             |    4 +-
 22 files changed, 81 insertions(+), 81 deletions(-)
---
diff --git a/addressbook/backends/file/e-book-backend-file.c b/addressbook/backends/file/e-book-backend-file.c
index 430dcf7..6b82509 100644
--- a/addressbook/backends/file/e-book-backend-file.c
+++ b/addressbook/backends/file/e-book-backend-file.c
@@ -1759,7 +1759,7 @@ e_book_backend_file_dup_locale (EBookBackend *backend)
 static EDataBookCursor *
 e_book_backend_file_create_cursor (EBookBackend *backend,
                                   EContactField *sort_fields,
-                                  EBookCursorSortType *sort_types,
+                                  EBookSortType *sort_types,
                                   guint n_fields,
                                   GError **error)
 {
diff --git a/addressbook/libebook/e-book-client-cursor.h b/addressbook/libebook/e-book-client-cursor.h
index 7e2bdff..5574a5f 100644
--- a/addressbook/libebook/e-book-client-cursor.h
+++ b/addressbook/libebook/e-book-client-cursor.h
@@ -136,7 +136,7 @@ gboolean             e_book_client_cursor_set_alphabetic_index_sync   (EBookClie
                                                                       gint                 index,
                                                                       GCancellable        *cancellable,
                                                                       GError             **error);
-gint                 e_book_client_cursor_get_contact_alphabetic_index(EBookClientCursor   *cursor,
+gint                 e_book_client_cursor_get_contact_alpabetic_index (EBookClientCursor   *cursor,
                                                                       EContact            *contact);
 
 G_END_DECLS
diff --git a/addressbook/libebook/e-book-client.c b/addressbook/libebook/e-book-client.c
index a695190..afb3220 100644
--- a/addressbook/libebook/e-book-client.c
+++ b/addressbook/libebook/e-book-client.c
@@ -88,7 +88,7 @@ struct _AsyncContext {
        GSList *object_list;
        GSList *string_list;
        EContactField *sort_fields;
-       EBookCursorSortType *sort_types;
+       EBookSortType *sort_types;
        guint n_sort_fields;
        gchar *sexp;
        gchar *uid;
@@ -3613,9 +3613,9 @@ sort_param_to_strv (gpointer param,
 
                        array[i] = e_contact_field_name (fields[i]);
                } else {
-                       EBookCursorSortType *types = (EBookCursorSortType *)param;
+                       EBookSortType *types = (EBookSortType *)param;
 
-                       array[i] = e_enum_to_string (E_TYPE_BOOK_CURSOR_SORT_TYPE,
+                       array[i] = e_enum_to_string (E_TYPE_BOOK_SORT_TYPE,
                                                     types[i]);
                }
        }
@@ -3754,7 +3754,7 @@ static void
 e_book_client_get_cursor_with_context (EBookClient *client,
                                       const gchar *sexp,
                                       EContactField *sort_fields,
-                                      EBookCursorSortType *sort_types,
+                                      EBookSortType *sort_types,
                                       guint n_fields,
                                       GMainContext *context,
                                       GCancellable *cancellable,
@@ -3772,7 +3772,7 @@ e_book_client_get_cursor_with_context (EBookClient *client,
        async_context = g_slice_new0 (AsyncContext);
        async_context->sexp = g_strdup (sexp);
        async_context->sort_fields = g_memdup (sort_fields, sizeof (EContactField) * n_fields);
-       async_context->sort_types = g_memdup (sort_types, sizeof (EBookCursorSortType) * n_fields);
+       async_context->sort_types = g_memdup (sort_types, sizeof (EBookSortType) * n_fields);
        async_context->n_sort_fields = n_fields;
        async_context->context = g_main_context_ref (context);
 
@@ -3797,7 +3797,7 @@ e_book_client_get_cursor_with_context (EBookClient *client,
  * @client: an #EBookClient
  * @sexp: an S-expression representing the query
  * @sort_fields: an array of #EContactFields to sort the cursor with
- * @sort_types: an array of #EBookCursorSortTypes to complement @sort_fields
+ * @sort_types: an array of #EBookSortTypes to complement @sort_fields
  * @n_fields: the length of the input @sort_fields and @sort_types arrays
  * @cancellable: a #GCancellable; can be %NULL
  * @callback: callback to call when a result is ready
@@ -3816,7 +3816,7 @@ void
 e_book_client_get_cursor (EBookClient *client,
                          const gchar *sexp,
                          EContactField *sort_fields,
-                         EBookCursorSortType *sort_types,
+                         EBookSortType *sort_types,
                          guint n_fields,
                          GCancellable *cancellable,
                          GAsyncReadyCallback callback,
@@ -3886,7 +3886,7 @@ e_book_client_get_cursor_finish (EBookClient *client,
  * @client: an #EBookClient
  * @sexp: an S-expression representing the query
  * @sort_fields: an array of #EContactFields to sort the cursor with
- * @sort_types: an array of #EBookCursorSortTypes to complement @sort_fields
+ * @sort_types: an array of #EBookSortTypes to complement @sort_fields
  * @n_fields: the length of the input @sort_fields and @sort_types arrays
  * @out_cursor: (out): return location for an #EBookClientCursor
  * @cancellable: a #GCancellable; can be %NULL
@@ -3907,7 +3907,7 @@ gboolean
 e_book_client_get_cursor_sync (EBookClient *client,
                               const gchar *sexp,
                               EContactField *sort_fields,
-                              EBookCursorSortType *sort_types,
+                              EBookSortType *sort_types,
                               guint n_fields,
                               EBookClientCursor **out_cursor,
                               GCancellable *cancellable,
diff --git a/addressbook/libebook/e-book-client.h b/addressbook/libebook/e-book-client.h
index 586213f..4b2d7a0 100644
--- a/addressbook/libebook/e-book-client.h
+++ b/addressbook/libebook/e-book-client.h
@@ -287,7 +287,7 @@ gboolean    e_book_client_get_view_sync     (EBookClient *client,
 void           e_book_client_get_cursor        (EBookClient *client,
                                                 const gchar *sexp,
                                                 EContactField *sort_fields,
-                                                EBookCursorSortType *sort_types,
+                                                EBookSortType *sort_types,
                                                 guint n_fields,
                                                 GCancellable *cancellable,
                                                 GAsyncReadyCallback callback,
@@ -299,7 +299,7 @@ gboolean    e_book_client_get_cursor_finish (EBookClient *client,
 gboolean       e_book_client_get_cursor_sync   (EBookClient *client,
                                                 const gchar *sexp,
                                                 EContactField *sort_fields,
-                                                EBookCursorSortType *sort_types,
+                                                EBookSortType *sort_types,
                                                 guint n_fields,
                                                 EBookClientCursor **out_cursor,
                                                 GCancellable *cancellable,
diff --git a/addressbook/libedata-book/e-book-backend-sqlitedb.h 
b/addressbook/libedata-book/e-book-backend-sqlitedb.h
index b2d03c5..fce7cae 100644
--- a/addressbook/libedata-book/e-book-backend-sqlitedb.h
+++ b/addressbook/libedata-book/e-book-backend-sqlitedb.h
@@ -125,7 +125,7 @@ typedef struct {
 typedef struct _EbSdbCursor EbSdbCursor;
 
 /**
- * EbSdbCursorOrigin:
+ * EbSdbCurorOrigin:
  * @EBSDB_CURSOR_ORIGIN_CURRENT:  The current cursor position
  * @EBSDB_CURSOR_ORIGIN_PREVIOUS: The previously recorded cursor position, this can be used to repeat the 
previous query
  * @EBSDB_CURSOR_ORIGIN_RESET:    The beginning of the cursor results (or end of the results, if navigating 
in reverse).
@@ -143,7 +143,7 @@ typedef enum {
        EBSDB_CURSOR_ORIGIN_CURRENT,
        EBSDB_CURSOR_ORIGIN_PREVIOUS,
        EBSDB_CURSOR_ORIGIN_RESET
-} EbSdbCursorOrigin;
+} EbSdbCurorOrigin;
 
 GType          e_book_backend_sqlitedb_get_type
                                                (void) G_GNUC_CONST;
@@ -328,7 +328,7 @@ EbSdbCursor    *e_book_backend_sqlitedb_cursor_new
                                                 const gchar          *folderid,
                                                 const gchar          *sexp,
                                                 EContactField        *sort_fields,
-                                                EBookCursorSortType  *sort_types,
+                                                EBookSortType        *sort_types,
                                                 guint                 n_sort_fields,
                                                 GError              **error);
 void            e_book_backend_sqlitedb_cursor_free
@@ -337,7 +337,7 @@ void            e_book_backend_sqlitedb_cursor_free
 gboolean        e_book_backend_sqlitedb_cursor_move_by
                                                 (EBookBackendSqliteDB *ebsdb,
                                                 EbSdbCursor          *cursor,
-                                                EbSdbCursorOrigin     origin,
+                                                EbSdbCurorOrigin      origin,
                                                 gint                  count,
                                                 GSList              **results,
                                                 GError              **error);
@@ -356,7 +356,7 @@ gboolean        e_book_backend_sqlitedb_cursor_calculate
                                                 gint                 *total,
                                                 gint                 *position,
                                                 GError              **error);
-gint            e_book_backend_sqlitedb_cursor_compare_contact
+gint            e_book_backend_sqlitedb_cursor_compare
                                                 (EBookBackendSqliteDB *ebsdb,
                                                 EbSdbCursor          *cursor,
                                                 EContact             *contact,
diff --git a/addressbook/libedata-book/e-book-backend.c b/addressbook/libedata-book/e-book-backend.c
index db5a791..cbb36f7 100644
--- a/addressbook/libedata-book/e-book-backend.c
+++ b/addressbook/libedata-book/e-book-backend.c
@@ -1511,7 +1511,7 @@ e_book_backend_respond_opened (EBookBackend *backend,
  * e_book_backend_create_cursor:
  * @backend: an #EBookBackend
  * @sort_fields: the #EContactFields to sort by
- * @sort_types: the #EBookCursorSortTypes for the sorted fields
+ * @sort_types: the #EBookSortTypes for the sorted fields
  * @n_fields: the number of fields in the @sort_fields and @sort_types
  * @error: return location for a #GError, or %NULL
  *
@@ -1533,7 +1533,7 @@ e_book_backend_respond_opened (EBookBackend *backend,
 EDataBookCursor *
 e_book_backend_create_cursor (EBookBackend *backend,
                              EContactField *sort_fields,
-                             EBookCursorSortType *sort_types,
+                             EBookSortType *sort_types,
                              guint n_fields,
                              GError **error)
 {
diff --git a/addressbook/libedata-book/e-book-backend.h b/addressbook/libedata-book/e-book-backend.h
index d8b8edb..cc702e2 100644
--- a/addressbook/libedata-book/e-book-backend.h
+++ b/addressbook/libedata-book/e-book-backend.h
@@ -209,7 +209,7 @@ struct _EBookBackendClass {
        EDataBookCursor *
                        (*create_cursor)        (EBookBackend *backend,
                                                 EContactField *sort_fields,
-                                                EBookCursorSortType *sort_types,
+                                                EBookSortType *sort_types,
                                                 guint n_fields,
                                                 GError **error);
        gboolean        (* delete_cursor)       (EBookBackend *backend,
@@ -323,7 +323,7 @@ gchar          *e_book_backend_dup_locale       (EBookBackend *backend);
 EDataBookCursor *
                 e_book_backend_create_cursor    (EBookBackend *backend,
                                                 EContactField *sort_fields,
-                                                EBookCursorSortType *sort_types,
+                                                EBookSortType *sort_types,
                                                 guint n_fields,
                                                 GError **error);
 gboolean        e_book_backend_delete_cursor    (EBookBackend *backend,
diff --git a/addressbook/libedata-book/e-data-book-cursor-sqlite.c 
b/addressbook/libedata-book/e-data-book-cursor-sqlite.c
index 99bad53..ad1d239 100644
--- a/addressbook/libedata-book/e-data-book-cursor-sqlite.c
+++ b/addressbook/libedata-book/e-data-book-cursor-sqlite.c
@@ -243,7 +243,7 @@ e_data_book_cursor_sqlite_set_sexp (EDataBookCursor     *cursor,
 
 static gboolean
 convert_origin (EBookCursorOrigin    src_origin,
-               EbSdbCursorOrigin   *dest_origin,
+               EbSdbCurorOrigin    *dest_origin,
                GError             **error)
 {
        gboolean success = TRUE;
@@ -281,7 +281,7 @@ e_data_book_cursor_sqlite_move_by (EDataBookCursor     *cursor,
        EDataBookCursorSqlite *cursor_sqlite;
        EDataBookCursorSqlitePrivate *priv;
        GSList *local_results = NULL, *local_converted_results = NULL, *l;
-       EbSdbCursorOrigin sqlitedb_origin = EBSDB_CURSOR_ORIGIN_CURRENT;
+       EbSdbCurorOrigin sqlitedb_origin = EBSDB_CURSOR_ORIGIN_CURRENT;
        gchar *revision = NULL;
        gboolean success = FALSE;
 
@@ -421,10 +421,10 @@ e_data_book_cursor_sqlite_compare_contact (EDataBookCursor     *cursor,
        cursor_sqlite = E_DATA_BOOK_CURSOR_SQLITE (cursor);
        priv = cursor_sqlite->priv;
 
-       return e_book_backend_sqlitedb_cursor_compare_contact (priv->ebsdb,
-                                                              priv->cursor,
-                                                              contact,
-                                                              matches_sexp);
+       return e_book_backend_sqlitedb_cursor_compare (priv->ebsdb,
+                                                      priv->cursor,
+                                                      contact,
+                                                      matches_sexp);
 }
 
 static gboolean
@@ -453,7 +453,7 @@ e_data_book_cursor_sqlite_load_locale (EDataBookCursor     *cursor,
  * @ebsdb: the #EBookBackendSqliteDB object to base this cursor on
  * @folder_id: the folder identifier to be used in EBookBackendSqliteDB API calls
  * @sort_fields: (array length=n_fields): an array of #EContactFields as sort keys in order of priority
- * @sort_types: (array length=n_fields): an array of #EBookCursorSortTypes, one for each field in 
@sort_fields
+ * @sort_types: (array length=n_fields): an array of #EBookSortTypes, one for each field in @sort_fields
  * @n_fields: the number of fields to sort results by.
  * @error: a return location to story any error that might be reported.
  *
@@ -472,7 +472,7 @@ e_data_book_cursor_sqlite_new (EBookBackend         *backend,
                               EBookBackendSqliteDB *ebsdb,
                               const gchar          *folder_id,
                               EContactField        *sort_fields,
-                              EBookCursorSortType  *sort_types,
+                              EBookSortType        *sort_types,
                               guint                 n_fields,
                               GError              **error)
 {
diff --git a/addressbook/libedata-book/e-data-book-cursor-sqlite.h 
b/addressbook/libedata-book/e-data-book-cursor-sqlite.h
index 88ea577..28b52ef 100644
--- a/addressbook/libedata-book/e-data-book-cursor-sqlite.h
+++ b/addressbook/libedata-book/e-data-book-cursor-sqlite.h
@@ -72,7 +72,7 @@ EDataBookCursor        *e_data_book_cursor_sqlite_new              (EBookBackend
                                                                    EBookBackendSqliteDB *ebsdb,
                                                                    const gchar          *folder_id,
                                                                    EContactField        *sort_fields,
-                                                                   EBookCursorSortType  *sort_types,
+                                                                   EBookSortType        *sort_types,
                                                                    guint                 n_fields,
                                                                    GError              **error);
 
diff --git a/addressbook/libedata-book/e-data-book.c b/addressbook/libedata-book/e-data-book.c
index ab3c396..81a5ab7 100644
--- a/addressbook/libedata-book/e-data-book.c
+++ b/addressbook/libedata-book/e-data-book.c
@@ -1119,13 +1119,13 @@ static gboolean
 data_book_interpret_sort_keys (const gchar * const *in_sort_keys,
                               const gchar * const *in_sort_types,
                               EContactField **out_sort_keys,
-                              EBookCursorSortType **out_sort_types,
+                              EBookSortType **out_sort_types,
                               gint *n_fields,
                               GError **error)
 {
        gint i, key_count = 0, type_count = 0;
        EContactField *sort_keys;
-       EBookCursorSortType *sort_types;
+       EBookSortType *sort_types;
        gboolean success = TRUE;
 
        if (!in_sort_keys || !in_sort_types) {
@@ -1150,7 +1150,7 @@ data_book_interpret_sort_keys (const gchar * const *in_sort_keys,
        }
 
        sort_keys = g_new0 (EContactField, key_count);
-       sort_types = g_new0 (EBookCursorSortType, type_count);
+       sort_types = g_new0 (EBookSortType, type_count);
 
        for (i = 0; success && i < key_count; i++) {
 
@@ -1169,7 +1169,7 @@ data_book_interpret_sort_keys (const gchar * const *in_sort_keys,
        for (i = 0; success && i < type_count; i++) {
                gint enum_value = 0;
 
-               if (!e_enum_from_string (E_TYPE_BOOK_CURSOR_SORT_TYPE,
+               if (!e_enum_from_string (E_TYPE_BOOK_SORT_TYPE,
                                         in_sort_types[i],
                                         &enum_value)) {
                        g_set_error (error,
@@ -1207,7 +1207,7 @@ data_book_handle_get_cursor_cb (EDBusAddressBook *interface,
        EDataBookCursor *cursor;
        GDBusConnection *connection;
        EContactField *sort_keys = NULL;
-       EBookCursorSortType *sort_types = NULL;
+       EBookSortType *sort_types = NULL;
        gint n_fields = 0;
        gchar *object_path;
        GError *error = NULL;
diff --git a/tests/cursor-example/cursor-data.c b/tests/cursor-example/cursor-data.c
index a2e8437..00e9961 100644
--- a/tests/cursor-example/cursor-data.c
+++ b/tests/cursor-example/cursor-data.c
@@ -290,7 +290,7 @@ static EBookClientCursor *
 get_cursor (EBookClient *book_client)
 {
   EContactField sort_fields[] = { E_CONTACT_FAMILY_NAME, E_CONTACT_GIVEN_NAME };
-  EBookCursorSortType sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING, E_BOOK_CURSOR_SORT_ASCENDING };
+  EBookSortType sort_types[] = { E_BOOK_SORT_ASCENDING, E_BOOK_SORT_ASCENDING };
   EBookClientCursor *cursor = NULL;
   GError *error = NULL;
 
diff --git a/tests/cursor-example/cursor-example.c b/tests/cursor-example/cursor-example.c
index 8efd4e4..547f46d 100644
--- a/tests/cursor-example/cursor-example.c
+++ b/tests/cursor-example/cursor-example.c
@@ -541,7 +541,7 @@ cursor_example_update_current_index (CursorExample *example,
        gint                  index;
 
        /* Fetch the alphabetic index for this contact */
-       index = e_book_client_cursor_get_contact_alphabetic_index (priv->cursor, contact);
+       index = e_book_client_cursor_get_contact_alpabetic_index (priv->cursor, contact);
 
        /* Refresh the current alphabet index indicator.
         *
diff --git a/tests/libebook/client/test-client-cursor-create.c 
b/tests/libebook/client/test-client-cursor-create.c
index 899bbb6..25795da 100644
--- a/tests/libebook/client/test-client-cursor-create.c
+++ b/tests/libebook/client/test-client-cursor-create.c
@@ -31,11 +31,11 @@ static ETestServerClosure book_closure_direct_async = { E_TEST_SERVER_DIRECT_ADD
 
 #define N_VALID_SORT_FIELDS 2
 static EContactField valid_sort_fields[] = { E_CONTACT_FAMILY_NAME, E_CONTACT_GIVEN_NAME };
-static EBookCursorSortType valid_sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING, E_BOOK_CURSOR_SORT_ASCENDING 
};
+static EBookSortType valid_sort_types[] = { E_BOOK_SORT_ASCENDING, E_BOOK_SORT_ASCENDING };
 
 #define N_INVALID_SORT_FIELDS 1
 static EContactField invalid_sort_fields[] = { E_CONTACT_TEL };
-static EBookCursorSortType invalid_sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING };
+static EBookSortType invalid_sort_types[] = { E_BOOK_SORT_ASCENDING };
 
 static void
 test_cursor_create_empty_query_sync (ETestServerFixture *fixture,
diff --git a/tests/libebook/client/test-client-cursor-operations.c 
b/tests/libebook/client/test-client-cursor-operations.c
index 964e5e1..3fcbef0 100644
--- a/tests/libebook/client/test-client-cursor-operations.c
+++ b/tests/libebook/client/test-client-cursor-operations.c
@@ -219,7 +219,7 @@ struct _CursorTest {
  ******************************************************/
 #define N_SORT_FIELDS 2
 static EContactField sort_fields[] = { E_CONTACT_FAMILY_NAME, E_CONTACT_GIVEN_NAME };
-static EBookCursorSortType sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING, E_BOOK_CURSOR_SORT_ASCENDING };
+static EBookSortType sort_types[] = { E_BOOK_SORT_ASCENDING, E_BOOK_SORT_ASCENDING };
 
 static gboolean
 cursor_timeout (const gchar *error_message)
diff --git a/tests/libedata-book/data-test-utils.c b/tests/libedata-book/data-test-utils.c
index b5f3ffc..5d435fc 100644
--- a/tests/libedata-book/data-test-utils.c
+++ b/tests/libedata-book/data-test-utils.c
@@ -225,7 +225,7 @@ e_sqlitedb_cursor_fixture_setup (EbSdbCursorFixture *fixture,
        ESqliteDBFixture *ebsdb_fixture = (ESqliteDBFixture *)fixture;
        EbSdbCursorClosure *data = (EbSdbCursorClosure *)user_data;
        EContactField sort_fields[] = { E_CONTACT_FAMILY_NAME, E_CONTACT_GIVEN_NAME };
-       EBookCursorSortType sort_types[] = { data->sort_type, data->sort_type };
+       EBookSortType sort_types[] = { data->sort_type, data->sort_type };
        EBookClient *book_client;
        GSList *contacts = NULL;
        GError *error = NULL;
@@ -495,7 +495,7 @@ move_by_test_new_internal (const gchar *test_path,
        data->parent.parent.type = E_TEST_SERVER_ADDRESS_BOOK;
        data->parent.parent.customize = e_sqlitedb_cursor_fixture_setup_book;
        data->parent.locale = g_strdup (locale);
-       data->parent.sort_type = E_BOOK_CURSOR_SORT_ASCENDING;
+       data->parent.sort_type = E_BOOK_SORT_ASCENDING;
        data->path = g_strdup (test_path);
        data->struct_size = struct_size;
 
@@ -524,7 +524,7 @@ move_by_test_new (const gchar *test_path,
 MoveByData *
 move_by_test_new_full (const gchar         *test_path,
                       const gchar         *locale,
-                      EBookCursorSortType  sort_type)
+                      EBookSortType        sort_type)
 {
        MoveByData *data;
 
diff --git a/tests/libedata-book/data-test-utils.h b/tests/libedata-book/data-test-utils.h
index 10108a6..ae2bd09 100644
--- a/tests/libedata-book/data-test-utils.h
+++ b/tests/libedata-book/data-test-utils.h
@@ -95,7 +95,7 @@ typedef struct {
        ETestServerClosure  parent;
 
        const gchar        *locale;
-       EBookCursorSortType sort_type;
+       EBookSortType       sort_type;
 } EbSdbCursorClosure;
 
 typedef struct {
@@ -157,7 +157,7 @@ MoveByData *move_by_test_new               (const gchar *test_path,
                                            const gchar *locale);
 MoveByData *move_by_test_new_full          (const gchar   *test_path,
                                            const gchar   *locale,
-                                           EBookCursorSortType sort_type);
+                                           EBookSortType sort_type);
 void        move_by_test_add               (MoveByData  *data,
                                            gboolean     filtered);
 
diff --git a/tests/libedata-book/test-sqlite-create-cursor.c b/tests/libedata-book/test-sqlite-create-cursor.c
index 399ad09..3479e78 100644
--- a/tests/libedata-book/test-sqlite-create-cursor.c
+++ b/tests/libedata-book/test-sqlite-create-cursor.c
@@ -14,7 +14,7 @@ test_create_cursor_empty_query (ESqliteDBFixture *fixture,
 {
        EbSdbCursor  *cursor;
        EContactField sort_fields[] = { E_CONTACT_FAMILY_NAME, E_CONTACT_GIVEN_NAME };
-       EBookCursorSortType sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING, E_BOOK_CURSOR_SORT_ASCENDING };
+       EBookSortType sort_types[] = { E_BOOK_SORT_ASCENDING, E_BOOK_SORT_ASCENDING };
        GError       *error = NULL;
 
        cursor = e_book_backend_sqlitedb_cursor_new (fixture->ebsdb, SQLITEDB_FOLDER_ID, NULL,
@@ -30,7 +30,7 @@ test_create_cursor_valid_query (ESqliteDBFixture *fixture,
 {
        EbSdbCursor  *cursor;
        EContactField sort_fields[] = { E_CONTACT_FAMILY_NAME, E_CONTACT_GIVEN_NAME };
-       EBookCursorSortType sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING, E_BOOK_CURSOR_SORT_ASCENDING };
+       EBookSortType sort_types[] = { E_BOOK_SORT_ASCENDING, E_BOOK_SORT_ASCENDING };
        EBookQuery   *query;
        gchar        *sexp;
        GError       *error = NULL;
@@ -53,7 +53,7 @@ test_create_cursor_invalid_query (ESqliteDBFixture *fixture,
 {
        EbSdbCursor  *cursor;
        EContactField sort_fields[] = { E_CONTACT_FAMILY_NAME, E_CONTACT_GIVEN_NAME };
-       EBookCursorSortType sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING, E_BOOK_CURSOR_SORT_ASCENDING };
+       EBookSortType sort_types[] = { E_BOOK_SORT_ASCENDING, E_BOOK_SORT_ASCENDING };
        EBookQuery   *query;
        gchar        *sexp;
        GError       *error = NULL;
@@ -78,7 +78,7 @@ test_create_cursor_invalid_sort (ESqliteDBFixture *fixture,
 {
        EbSdbCursor  *cursor;
        EContactField sort_fields[] = { E_CONTACT_TEL };
-       EBookCursorSortType sort_types[] = { E_BOOK_CURSOR_SORT_ASCENDING };
+       EBookSortType sort_types[] = { E_BOOK_SORT_ASCENDING };
        GError       *error = NULL;
 
        cursor = e_book_backend_sqlitedb_cursor_new (fixture->ebsdb, SQLITEDB_FOLDER_ID, NULL,
diff --git a/tests/libedata-book/test-sqlite-cursor-calculate.c 
b/tests/libedata-book/test-sqlite-cursor-calculate.c
index 2d1621f..fc9a99f 100644
--- a/tests/libedata-book/test-sqlite-cursor-calculate.c
+++ b/tests/libedata-book/test-sqlite-cursor-calculate.c
@@ -9,13 +9,13 @@
 static EbSdbCursorClosure ascending_closure = {
        { E_TEST_SERVER_ADDRESS_BOOK, e_sqlitedb_cursor_fixture_setup_book, 0 },
        NULL, 
-       E_BOOK_CURSOR_SORT_ASCENDING
+       E_BOOK_SORT_ASCENDING
 };
 
 static EbSdbCursorClosure descending_closure = {
        { E_TEST_SERVER_ADDRESS_BOOK, e_sqlitedb_cursor_fixture_setup_book, 0 },
        NULL, 
-       E_BOOK_CURSOR_SORT_DESCENDING
+       E_BOOK_SORT_DESCENDING
 };
 
 static void
diff --git a/tests/libedata-book/test-sqlite-cursor-move-by-en-US.c 
b/tests/libedata-book/test-sqlite-cursor-move-by-en-US.c
index 2876a16..dc8f4c0 100644
--- a/tests/libedata-book/test-sqlite-cursor-move-by-en-US.c
+++ b/tests/libedata-book/test-sqlite-cursor-move-by-en-US.c
@@ -43,7 +43,7 @@ main (gint argc,
        move_by_test_add (data, TRUE);
 
        data = move_by_test_new_full ("/EbSdbCursor/en_US/Move/Descending/Forward", "en_US.UTF-8",
-                                     E_BOOK_CURSOR_SORT_DESCENDING);
+                                     E_BOOK_SORT_DESCENDING);
        move_by_test_add_assertion (data, 5, 20, 19, 9,  13, 12);
        move_by_test_add_assertion (data, 5, 14, 10, 18, 16, 17);
        move_by_test_add_assertion (data, 5, 15, 8,  7,  3,  4);
@@ -51,7 +51,7 @@ main (gint argc,
        move_by_test_add (data, FALSE);
 
        data = move_by_test_new_full ("/EbSdbCursor/en_US/Move/Descending/Forward/Loop", "en_US.UTF-8",
-                                     E_BOOK_CURSOR_SORT_DESCENDING);
+                                     E_BOOK_SORT_DESCENDING);
        move_by_test_add_assertion (data, 10, 20, 19, 9,  13, 12, 14, 10, 18, 16, 17);
        move_by_test_add_assertion (data, 11, 15, 8,  7,  3,  4, 6,  5,  2,  1,  11, 0);
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/addressbook/libebook-contacts/e-book-contacts-types.h 
b/addressbook/libebook-contacts/e-book-contacts-types.h
index 4287156..4dc5231 100644
--- a/addressbook/libebook-contacts/e-book-contacts-types.h
+++ b/addressbook/libebook-contacts/e-book-contacts-types.h
@@ -136,18 +136,18 @@ typedef enum {
 } EBookIndexType;
 
 /**
  * EBookCursorSortType:
  * @E_BOOK_CURSOR_SORT_ASCENDING: Sort results in ascending order
  * @E_BOOK_CURSOR_SORT_DESCENDING: Sort results in descending order
  *
  * Specifies the sort order of an ordered query
  *
  * Since: 3.12
  */
 typedef enum {
-       E_BOOK_CURSOR_SORT_ASCENDING = 0,
-       E_BOOK_CURSOR_SORT_DESCENDING
-} EBookCursorSortType;
+       E_BOOK_SORT_ASCENDING = 0,
+       E_BOOK_SORT_DESCENDING
+} EBookSortType;
 
 /**
  * EBookCursorOrigin:
@@ -136,18 +136,18 @@ typedef enum {
 
 /**
- * EBookCursorSortType:
- * @E_BOOK_CURSOR_SORT_ASCENDING: Sort results in ascending order
- * @E_BOOK_CURSOR_SORT_DESCENDING: Sort results in descending order
+ * EBookSortType:
+ * @E_BOOK_SORT_ASCENDING: Sort results in ascending order
+ * @E_BOOK_SORT_DESCENDING: Sort results in descending order
  *
  * Specifies the sort order of an ordered query
diff --git a/addressbook/libebook/e-book-client-cursor.c b/addressbook/libebook/e-book-client-cursor.c
index f0270d2..63c04fe 100644
--- a/addressbook/libebook/e-book-client-cursor.c
+++ b/addressbook/libebook/e-book-client-cursor.c
@@ -193,7 +193,7 @@
  * </para>
  * <para>
  * One can determine the appropriate index for a given #EContact by calling
  * e_book_client_cursor_get_contact_alphabetic_index(), this is useful to use
  * when updating any indicators in the user interface showing what letter
  * you have reached in the active alphabet.
  * </para>
@@ -2459,7 +2459,7 @@ e_book_client_cursor_set_alphabetic_index_sync (EBookClientCursor   *cursor,
 }
 
 /**
- * e_book_client_cursor_get_contact_alphabetic_index:
+ * e_book_client_cursor_get_contact_alpabetic_index:
  * @cursor: an #EBookClientCursor
  * @contact: the #EContact to check
  *
@@ -2474,8 +2474,8 @@ e_book_client_cursor_set_alphabetic_index_sync (EBookClientCursor   *cursor,
  * Since: 3.12
  */
 gint
-e_book_client_cursor_get_contact_alphabetic_index (EBookClientCursor   *cursor,
-                                                  EContact            *contact)
+e_book_client_cursor_get_contact_alpabetic_index (EBookClientCursor   *cursor,
+                                                 EContact            *contact)
 {
        EBookClientCursorPrivate *priv;
        EContactField field;
@@ -193,7 +193,7 @@
  * <para>
  * One can determine the appropriate index for a given #EContact by calling
- * e_book_client_cursor_get_contact_alphabetic_index(), this is useful to use
+ * e_book_client_cursor_get_contact_alpabetic_index(), this is useful to use
  * when updating any indicators in the user interface showing what letter
  * you have reached in the active alphabet.
diff --git a/addressbook/libedata-book/e-book-backend-sqlitedb.c 
b/addressbook/libedata-book/e-book-backend-sqlitedb.c
index 349f213..d23fe8e 100644
--- a/addressbook/libedata-book/e-book-backend-sqlitedb.c
+++ b/addressbook/libedata-book/e-book-backend-sqlitedb.c
@@ -5270,7 +5270,7 @@ struct _EbSdbCursor {
        gchar         *reverse_order; /* The reverse order SQL query fragment to append at the end, 
containing ORDER BY etc */
 
        EContactField       *sort_fields;   /* The fields to sort in a query in the order or sort priority */
-       EBookCursorSortType *sort_types;    /* The sort method to use for each field */
+       EBookSortType       *sort_types;    /* The sort method to use for each field */
        gint                 n_sort_fields; /* The amound of sort fields */
 
        CursorState    state[N_CURSOR_STATES];
@@ -5323,7 +5323,7 @@ ebsdb_cursor_setup_query (EBookBackendSqliteDB *ebsdb,
 static gchar *
 ebsdb_cursor_order_by_fragment (EBookBackendSqliteDB *ebsdb,
                                EContactField        *sort_fields,
-                               EBookCursorSortType  *sort_types,
+                               EBookSortType        *sort_types,
                                guint                 n_sort_fields,
                                gboolean              reverse)
 {
@@ -5342,8 +5342,8 @@ ebsdb_cursor_order_by_fragment (EBookBackendSqliteDB *ebsdb,
 
                g_string_append_printf (string, "summary.%s_localized %s", field_name,
                                        reverse ?
-                                       (sort_types[i] == E_BOOK_CURSOR_SORT_ASCENDING ? "DESC" : "ASC") :
-                                       (sort_types[i] == E_BOOK_CURSOR_SORT_ASCENDING ? "ASC"  : "DESC"));
+                                       (sort_types[i] == E_BOOK_SORT_ASCENDING ? "DESC" : "ASC") :
+                                       (sort_types[i] == E_BOOK_SORT_ASCENDING ? "ASC"  : "DESC"));
        }
 
        /* Also order the UID, since it's our tie breaker, we must also order the UID field */
@@ -5360,7 +5360,7 @@ ebsdb_cursor_new (EBookBackendSqliteDB *ebsdb,
                  const gchar          *sexp,
                  gboolean              query_with_list_attrs,
                  EContactField        *sort_fields,
-                 EBookCursorSortType  *sort_types,
+                 EBookSortType        *sort_types,
                  guint                 n_sort_fields)
 {
        EbSdbCursor *cursor = g_slice_new0 (EbSdbCursor);
@@ -5384,7 +5384,7 @@ ebsdb_cursor_new (EBookBackendSqliteDB *ebsdb,
 
        cursor->n_sort_fields = n_sort_fields;
        cursor->sort_fields   = g_memdup (sort_fields, sizeof (EContactField) * n_sort_fields);
-       cursor->sort_types    = g_memdup (sort_types,  sizeof (EBookCursorSortType) * n_sort_fields);
+       cursor->sort_types    = g_memdup (sort_types,  sizeof (EBookSortType) * n_sort_fields);
 
        for (i = 0; i < N_CURSOR_STATES; i++)
                cursor->state[i].values = g_new0 (gchar *, n_sort_fields);
@@ -5489,8 +5489,8 @@ ebsdb_cursor_set_state (EBookBackendSqliteDB *ebsdb,
 
 #define GREATER_OR_LESS(cursor, index, reverse)                                \
        (reverse ?                                                      \
-        (((EbSdbCursor *)cursor)->sort_types[index] == E_BOOK_CURSOR_SORT_ASCENDING ? '<' : '>') : \
-        (((EbSdbCursor *)cursor)->sort_types[index] == E_BOOK_CURSOR_SORT_ASCENDING ? '>' : '<'))
+        (((EbSdbCursor *)cursor)->sort_types[index] == E_BOOK_SORT_ASCENDING ? '<' : '>') : \
+        (((EbSdbCursor *)cursor)->sort_types[index] == E_BOOK_SORT_ASCENDING ? '>' : '<'))
 
 static gchar *
 ebsdb_cursor_constraints (EBookBackendSqliteDB *ebsdb,
@@ -5710,7 +5710,7 @@ cursor_count_position_locked (EBookBackendSqliteDB *ebsdb,
  * @folderid: folder id of the address-book
  * @sexp: search expression; use NULL or an empty string to get all stored contacts.
  * @sort_fields: (array length=n_sort_fields): An array of #EContactFields as sort keys in order of priority
- * @sort_types: (array length=n_sort_fields): An array of #EBookCursorSortTypes, one for each field in 
@sort_fields
+ * @sort_types: (array length=n_sort_fields): An array of #EBookSortTypes, one for each field in @sort_fields
  * @n_sort_fields: The number of fields to sort results by.
  * @error: A return location to store any error that might be reported.
  *
@@ -5727,7 +5727,7 @@ e_book_backend_sqlitedb_cursor_new (EBookBackendSqliteDB *ebsdb,
                                    const gchar          *folderid,
                                    const gchar          *sexp,
                                    EContactField        *sort_fields,
-                                   EBookCursorSortType  *sort_types,
+                                   EBookSortType        *sort_types,
                                    guint                 n_sort_fields,
                                    GError              **error)
 {
@@ -5837,7 +5837,7 @@ collect_results_for_cursor_cb (gpointer ref,
  * e_book_backend_sqlitedb_cursor_move_by:
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor to use
  * @origin: The #EbSdbCursorOrigin for this move
  * @count: A positive or negative amount of contacts to try and fetch
  * @results: (out) (allow-none) (element-type EbSdbSearchData) (transfer full):
  *   A return location to store the results, or %NULL to move the cursor without retrieving any results.
@@ -5867,7 +5867,7 @@ collect_results_for_cursor_cb (gpointer ref,
 gboolean
 e_book_backend_sqlitedb_cursor_move_by (EBookBackendSqliteDB *ebsdb,
                                        EbSdbCursor          *cursor,
-                                       EbSdbCursorOrigin     origin,
+                                       EbSdbCurorOrigin      origin,
                                        gint                  count,
                                        GSList              **results,
                                        GError              **error)
@@ -6147,7 +6147,7 @@ e_book_backend_sqlitedb_cursor_calculate (EBookBackendSqliteDB *ebsdb,
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_compare_contact:
+ * e_book_backend_sqlitedb_cursor_compare:
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor
  * @contact: The #EContact to compare
@@ -6162,10 +6162,10 @@ e_book_backend_sqlitedb_cursor_calculate (EBookBackendSqliteDB *ebsdb,
  * Since: 3.12
  */
 gint
-e_book_backend_sqlitedb_cursor_compare_contact (EBookBackendSqliteDB *ebsdb,
-                                               EbSdbCursor          *cursor,
-                                               EContact             *contact,
-                                               gboolean             *matches_sexp)
+e_book_backend_sqlitedb_cursor_compare (EBookBackendSqliteDB *ebsdb,
+                                       EbSdbCursor          *cursor,
+                                       EContact             *contact,
+                                       gboolean             *matches_sexp)
 {
        EBookBackendSqliteDBPrivate *priv;
        gint i;
@@ -5837,7 +5837,7 @@ collect_results_for_cursor_cb (gpointer ref,
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor to use
- * @origin: The #EbSdbCursorOrigin for this move
+ * @origin: The #EbSdbCurorOrigin for this move
  * @count: A positive or negative amount of contacts to try and fetch
  * @results: (out) (allow-none) (element-type EbSdbSearchData) (transfer full):